import VueI18Next from '@panter/vue-i18next'
import { get_vuetify_options as get_ferda_vuetify_options } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Fetch from 'i18next-fetch-backend'
import LocalStorageBackend from 'i18next-localstorage-backend'
import Vue from 'vue'
import Vuex, { Store as VuexStore } from 'vuex'
import YAML from 'yaml'

import { ICON_VALUES } from 'ferda_pubreq/icons.js'

import { PluginStore } from './store'

Vue.use(Vuex)
Vue.use(VueI18Next)

export const get_pubreq_vuetify_options = () => {
    const options = get_ferda_vuetify_options()
    options.icons.values = {
        ...options.icons.values,
        ...ICON_VALUES,
    }
    return options
}

export const store = new VuexStore(PluginStore)

export const get_ferda_pubreq_i18next_options = (ferda_version) => ({
    lng: store.getters['preferences/selected_language'],
    fallbackLng: [store.getters['settings/LANGUAGE_CODE'], 'en'],
    ns: [
        'ferda_pubreq_common',
        'ferda_pubreq_detail',
        'ferda_pubreq_list',
        'ferda_pubreq_rule',
        'common',
        'logger',
        'login',
        'notifications',
        'rule',
        'search',
    ],
    defaultNS: 'ferda_pubreq_common',
    backend: {
        backends: [LocalStorageBackend, Fetch],
        backendOptions: [
            {
                versions: store.getters['settings/LANGUAGES'].reduce((language_versions, lang) => {
                    language_versions[lang] = ferda_version
                    return language_versions
                }, {}),
            },
            {
                loadPath: '/static/ferda_pubreq/locales/{{lng}}/{{ns}}.yml',
                requestOptions: { cache: 'reload' },
                parse: data => YAML.parse(data),
            },
        ],
    },
})

export const i18n = new VueI18Next(i18next)
