import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import { i18n } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import PubreqBaseView from 'ferda_pubreq/PubreqBaseView.vue'
import PubreqObjectDetail from 'ferda_pubreq/common/PubreqObjectDetail.vue'

import { get_ferda_pubreq_i18next_options, get_pubreq_vuetify_options, store } from './main.config'
import router from './router'

Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

// Listen for store changes from Ferda and sync them with the store here
document.addEventListener('storechange', event => {
    const { payload, type } = event.detail
    const value = payload.value ? payload.value : payload

    if (store._mutations[type]) {
        store.commit(type, value)
    }
})

const destination = document.currentScript.dataset.destination

document.addEventListener('ferda-loaded', async({ detail }) => {
    await i18next.use(Backend).init(get_ferda_pubreq_i18next_options(detail.settings.django_settings.version))
    const permissions = detail.store_getters['general/permissions']

    if (destination === 'pubreq-module') {
        const pubreq_el = document.querySelector('#pubreq')
        if (pubreq_el) {
            new Vue({
                el: '#pubreq',
                name: 'PubreqIndex',
                vuetify: new Vuetify(get_pubreq_vuetify_options()),
                i18n,
                store,
                router,
                components: { PubreqBaseView },
                render: createElement => createElement(PubreqBaseView, { props: { permissions }}),
            })
        }
    }

    if (['contact-detail', 'domain-detail', 'nsset-detail', 'keyset-detail'].includes(destination)) {
        const object_type = destination.split('-')[0]
        const object_detail = JSON.parse(document.querySelector(`#${object_type}-data`).textContent)

        const ferda_pubreq_section_el = document.createElement('div')
        ferda_pubreq_section_el.id = 'pubreq-section'

        document.querySelector('.v-main__wrap > div > div:nth-child(2) > div > div:nth-child(4)')
            .appendChild(ferda_pubreq_section_el)

        new Vue({
            el: '#pubreq-section',
            name: 'PubreqSection',
            vuetify: new Vuetify(get_pubreq_vuetify_options()),
            i18n,
            store,
            render: createElement => createElement(PubreqObjectDetail, { props: {
                permissions,
                object_type,
                object_uuid: object_detail.object_uuid,
            }}),
        })
    }
})

window.addEventListener('popstate', () => {
    location.reload()
})

export { i18next }
