/**
 * Waits for the element until it is present in the DOM
 *
 * @param { String } selector - particular node selector
 * @returns { Object } - resolved or rejected promise
 */
export const wait_for_element = selector => {
    return new Promise(resolve => {
        // Return element if it is present
        const element = document.querySelector(selector)
        if (element) {
            resolve(element)
            return
        }

        // Otherwise observe for another mutation
        new MutationObserver((_, observer) => {
            for (const element of document.querySelectorAll(selector)) {
                resolve(element)
                observer.disconnect()
            }
        }).observe(document.documentElement, { childList: true, subtree: true })
    })
}
