"""Ferda public request urls."""

from asgiref.sync import sync_to_async
from django.conf import settings
from django.urls import path
from ferda.api import PydanticJsonRenderer
from ninja import NinjaAPI
from ninja.security import django_auth

from ferda_pubreq.views import PubreqIndexView

from .api import router

api = NinjaAPI(
    urls_namespace="ferda_pubreq:api",
    # Show API docs in debug mode only
    openapi_url=settings.DEBUG and "/openapi.json" or "",
    auth=sync_to_async(django_auth),
    renderer=PydanticJsonRenderer(),
)
api.add_router("/public-request/", router)

app_name = "ferda_pubreq"

urlpatterns = [
    path("", PubreqIndexView.as_view(), name="index"),
    path("api/", api.urls),
]
